@@ -67,7 +67,9 @@ pub enum Step {
     Atom,
     BrewCask,
     BrewFormula,
+    Bin,
     Cargo,
+    Chezmoi,
     Chocolatey,
     Choosenim,
     Composer,
@@ -82,6 +84,8 @@ pub enum Step {
     Gcloud,
     Gem,
     GitRepos,
+    Haxelib,
+    GnomeShellExtensions,
     HomeManager,
     Jetpack,
     Krew,
@@ -92,10 +96,13 @@ pub enum Step {
     Nix,
     Node,
     Opam,
+    Pacstall,
     Pearl,
     Pipx,
     Pip3,
     Pkg,
+    Pkgin,
+    Pnpm,
     Powershell,
     Raco,
     Remotes,
@@ -104,6 +111,7 @@ pub enum Step {
     Rustup,
     Scoop,
     Sdkman,
+    Silnite,
     Sheldon,
     Shell,
     Snap,
@@ -115,6 +123,7 @@ pub enum Step {
     Vagrant,
     Vcpkg,
     Vim,
+    Winget,
     Wsl,
     Yadm,
 }
@@ -144,21 +153,54 @@ pub struct Windows {
     open_remotes_in_new_terminal: Option<bool>,
 }
 
+#[derive(Deserialize, Default, Debug)]
+#[serde(deny_unknown_fields)]
+#[allow(clippy::upper_case_acronyms)]
+pub struct NPM {
+    use_sudo: Option<bool>,
+}
+
+#[derive(Deserialize, Default, Debug)]
+#[serde(deny_unknown_fields)]
+#[allow(clippy::upper_case_acronyms)]
+pub struct Firmware {
+    upgrade: Option<bool>,
+}
+
+#[derive(Deserialize, Default, Debug)]
+#[serde(deny_unknown_fields)]
+#[allow(clippy::upper_case_acronyms)]
+pub struct Flatpak {
+    use_sudo: Option<bool>,
+}
+
 #[derive(Deserialize, Default, Debug)]
 #[serde(deny_unknown_fields)]
 pub struct Brew {
     greedy_cask: Option<bool>,
 }
 
+#[derive(Debug, Deserialize, Clone, Copy)]
+#[serde(rename_all = "snake_case")]
+pub enum ArchPackageManager {
+    Autodetect,
+    Trizen,
+    Paru,
+    Yay,
+    Pacman,
+}
+
 #[derive(Deserialize, Default, Debug)]
 #[serde(deny_unknown_fields)]
 pub struct Linux {
     yay_arguments: Option<String>,
+    arch_package_manager: Option<ArchPackageManager>,
     trizen_arguments: Option<String>,
     dnf_arguments: Option<String>,
     apt_arguments: Option<String>,
     enable_tlmgr: Option<bool>,
     redhat_distro_sync: Option<bool>,
+    rpm_ostree: Option<bool>,
     emerge_sync_flags: Option<String>,
     emerge_update_flags: Option<String>,
 }
@@ -200,7 +242,10 @@ pub struct ConfigFile {
     linux: Option<Linux>,
     git: Option<Git>,
     windows: Option<Windows>,
+    npm: Option<NPM>,
+    firmware: Option<Firmware>,
     vagrant: Option<Vagrant>,
+    flatpak: Option<Flatpak>,
 }
 
 fn config_directory(base_dirs: &BaseDirs) -> PathBuf {
@@ -255,7 +300,7 @@ impl ConfigFile {
         })?;
 
         if let Some(ref mut paths) = &mut result.git_repos {
-            for path in paths.iter_mut() {
+            for path in paths {
                 let expanded = shellexpand::tilde::<&str>(&path.as_ref()).into_owned();
                 debug!("Path {} expanded to {}", path, expanded);
                 *path = expanded;
@@ -263,7 +308,7 @@ impl ConfigFile {
         }
 
         if let Some(paths) = result.git.as_mut().and_then(|git| git.repos.as_mut()) {
-            for path in paths.iter_mut() {
+            for path in paths {
                 let expanded = shellexpand::tilde::<&str>(&path.as_ref()).into_owned();
                 debug!("Path {} expanded to {}", path, expanded);
                 *path = expanded;
@@ -589,14 +634,23 @@ impl Config {
     /// Extra trizen arguments
     #[allow(dead_code)]
     pub fn trizen_arguments(&self) -> &str {
-        &self
-            .config_file
+        self.config_file
             .linux
             .as_ref()
             .and_then(|s| s.trizen_arguments.as_deref())
             .unwrap_or("")
     }
 
+    /// Extra yay arguments
+    #[allow(dead_code)]
+    pub fn arch_package_manager(&self) -> ArchPackageManager {
+        self.config_file
+            .linux
+            .as_ref()
+            .and_then(|s| s.arch_package_manager)
+            .unwrap_or(ArchPackageManager::Autodetect)
+    }
+
     /// Extra yay arguments
     #[allow(dead_code)]
     pub fn yay_arguments(&self) -> &str {
@@ -669,6 +723,16 @@ impl Config {
             .unwrap_or(false)
     }
 
+    /// Use rpm-ostree in *when rpm-ostree is detected* (default: true)
+    #[allow(dead_code)]
+    pub fn rpm_ostree(&self) -> bool {
+        self.config_file
+            .linux
+            .as_ref()
+            .and_then(|linux| linux.rpm_ostree)
+            .unwrap_or(true)
+    }
+
     /// Should we ignore failures for this step
     pub fn ignore_failure(&self, step: Step) -> bool {
         self.config_file
@@ -699,6 +763,33 @@ impl Config {
             .unwrap_or(false)
     }
 
+    #[cfg(target_os = "linux")]
+    pub fn npm_use_sudo(&self) -> bool {
+        self.config_file
+            .npm
+            .as_ref()
+            .and_then(|npm| npm.use_sudo)
+            .unwrap_or(false)
+    }
+
+    #[cfg(target_os = "linux")]
+    pub fn firmware_upgrade(&self) -> bool {
+        self.config_file
+            .firmware
+            .as_ref()
+            .and_then(|firmware| firmware.upgrade)
+            .unwrap_or(false)
+    }
+
+    #[cfg(target_os = "linux")]
+    pub fn flatpak_use_sudo(&self) -> bool {
+        self.config_file
+            .flatpak
+            .as_ref()
+            .and_then(|flatpak| flatpak.use_sudo)
+            .unwrap_or(false)
+    }
+
     #[cfg(target_os = "linux")]
     str_value!(linux, emerge_sync_flags);
 
